#
# spec file for package python-ruamel.yaml
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-ruamel.yaml
VCS: https://src.suse.de/SLFO-pool/python-ruamel.yaml#bd55abe3e3fa05ac8b7203bdc3d9fd2a424d18b6a9491a199c0fc463bdfd1d97
Version:        0.18.6
Release:        160000.1.6
Summary:        Python YAML parser
License:        MIT
URL:            https://sourceforge.net/p/ruamel-yaml
Source:         https://files.pythonhosted.org/packages/source/r/ruamel.yaml/ruamel.yaml-%{version}.tar.gz
Patch0:         0000-fix-big-endian-issues.patch
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-ruamel.yaml.clib >= 0.2.0
BuildArch:      noarch
%python_subpackages

%description
ruamel.yaml is a YAML parser/emitter that supports roundtrip preservation
of comments, seq/map flow style, and map key order.

%prep
%autosetup -p1 -n ruamel.yaml-%{version}
rm -rf *egg-info

%build
%python_build

%install
%python_install --single-version-externally-managed
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%files %{python_files}
%license LICENSE
%doc CHANGES README.md
%{python_sitelib}/ruamel
%{python_sitelib}/ruamel.yaml-%{version}*-info

%changelog
* Sat Mar 16 2024 opensuse_buildservice@ojkastl.de
- update to 0.18.6:
  * fixed an issue with dataclass loading when the fields were
    collections (bug found as a result of a question by
    [FibroMyAlgebra](https://stackoverflow.com/users/6855070/fibromyalgebra)
    on
    [StackOverflow](https://stackoverflow.com/a/77485786/1307905))
  * fixed an issue loading dataclasses with `InitVar` fields when
    `from __future__ import annotations` was used to delay
    evaluation of typing.
* Sat Mar 16 2024 opensuse_buildservice@ojkastl.de
- update to 0.18.5:
  * there is some indication that dependent packages have been
    pinned to use specific (tested) and just install the latest
    even in Python versions that have end-of-life
- update to 0.18.4:
  * YAML() instance has a `doc_infos` attribute which is a
    cumulative list of DocInfo instances (one for `load()`, one per
    document for `load_all()`). DocInfo instances contain version
    information (requested, directive) and tag directive
    information
  * fix issue that the YAML instance tags attribute was not reset
    between documents, resulting in mixing of tag directives of
    multiple documents. Now only provides tag directive information
    on latest document after loading. This means tags for dumping
    must be set **again** after a document is loaded with the same
    instance. (because of this tags will be removed in a favour of
    a different mechanism in the future)
  * fix issue with multiple document intermixing YAML 1.2 and YAML
    1.1, the VersionedResolver now resets
  * fix issue with disappearing comment when next token was Tag
    (still can't have both a comment before a tag and after a tag,
    before node)
* Sat Mar 16 2024 opensuse_buildservice@ojkastl.de
- update to 0.18.3:
  * fix issue with spurious newline on first item after comment +
    nested block sequence
  * additional links in the metadata on PyPI (Reported, with
    pointers how to fix, by
    [Sorin](https://sourceforge.net/u/ssbarnea/profile/)).
* Sat Mar 16 2024 opensuse_buildservice@ojkastl.de
- update to 0.18.2:
  * calling the deprecated functions now raises an `AttributeError`
    with the, somewhat more informative, orginal warning message.
    Instead of calling `sys.exit(1)`
* Sat Mar 16 2024 opensuse_buildservice@ojkastl.de
- update to 0.18.1:
  * calling the deprecated functions now always displays the
    warning message.  (reported by [Trend
    Lloyd](https://sourceforge.net/u/lathiat2/profile/))
* Sat Mar 16 2024 opensuse_buildservice@ojkastl.de
- update to 0.18.0:
  * the **functions** `scan`, `parse`, `compose`, `load`, `emit`,
    `serialize`, `dump` and their variants (`_all`, `safe_`,
    `round_trip_`, etc) have been deprecated (the same named
  * *methods** on `YAML()` instances are, of course, still there.
  * `YAML(typ='unsafe')` now issues a `PendingDeprecationWarning`.
    This will become deprecated in the 0.18 series (probably before
    the end of 2023).  You can use `YAML(typ='full')` to dump
    unregistered Python classes/functions.  For loading you'll have
    to register your classes/functions if you want the old, unsafe,
    functionality. You can still load any tag, like
    `!!python/name:posix.system', **safely** with the (default)
    round-trip parser.
  * fix for `bytes-like object is required not 'str' while dumping
    binary streams`.  This was reported, analysed and a fix
    provided by [Vit
    Zikmund](https://sourceforge.net/u/tlwhitec/profile/)
* Sat Mar 16 2024 opensuse_buildservice@ojkastl.de
- update to 0.17.40:
  * flow style sets are now preserved ( `!!set {a, b, c} )`. Any
    values specified when loading are dropped, including `!!null
    ""`.
  * potential workaround for issue 484: the
    long_description_content_type including the variant
    specification `CommonMark` can result in problems on Azure. If
    you can install from `.tar.gz` using
    `RUAMEL_NO_LONG_DESCRIPTION=1 pip install ruamel.yaml
  - -no-binary :all:` then the long description, and its offending
    type, are nog included (in the METADATA).  (Reported by [Coury
    Ditch](https://sourceforge.net/u/cmditch/profile/))
  * links in documentation update (reported by [David
    Hoese](https://sourceforge.net/u/daveydave400/profile/))
  * Added some `__repr__` for internally used classes
* Sat Mar 16 2024 opensuse_buildservice@ojkastl.de
- update to 0.17.39 (skipping non-existent releases .37 and .38):
  * update README generation, no code changes
* Sat Mar 16 2024 opensuse_buildservice@ojkastl.de
- update to 0.17.36:
  * fixed issue 480, dumping of a loaded empty flow-style mapping with comment failed
    (Reported by [Stéphane Brunner](https://sourceforge.net/u/stbrunner/profile/))
  * fixed issue 482, caused by DEFAULT_MAPPING_TAG having changes to being a `Tag()`
    instance, not a string (reported by [yan12125](https://sourceforge.net/u/yan12125/profile/))
  * updated documentation to use mkdocs
* Wed Oct  4 2023 mimi.vx@gmail.com
- update to 0.17.35
  * Python 3.12 also loads C version when using `typ='safe'`
  * initial support for loading invoking `__post_init__` on dataclasses
    that have that method after loading a registered dataclass
    (`@yaml.register_class\n@dataclass\nclass ...`)
  * fix issue with scanner getting stuck in infinite loop
  * added `flow_seq_start`, `flow_seq_end`, `flow_seq_separator`,
    `flow_map_start`, `flow_map_end`, `flow_map_separator` **class**
    attributes to the `Emitter` class so flow style output
    can more easily be influenced
* Thu Jun  1 2023 kastl@b1-systems.de
- update to 0.17.31:
  * added tag.setter on `ScalarEvent` and on `Node`, that takes
    either a `Tag` instance, or a str (reported by Sorin Sbarnea)
- update to 0.17.30:
  * fix issue 467, caused by Tag instances not being hashable
    (reported by Douglas Raillard)
- update to 0.17.29:
  * changed the internals of the tag property from a string to a
    class which allows for preservation of the original handle and
    suffix. This should result in better results using documents
    with %%TAG directives, as well as preserving URI escapes in tag
    suffixes.
- update to 0.17.28:
  * fix for issue 464: documents ending with document end marker
    without final newline fail to load (reported by Mariusz
    Rusiniak)
- update to 0.17.27:
  * fix issue with inline mappings as value for merge keys
    (reported by Sirish)
  * fix for 468, error inserting after accessing merge attribute on
    ``CommentedMap`` (reported by Bastien gerard)
  * fix for issue 461 pop + insert on same `CommentedMap` key
    throwing error (reported by `John Thorvald Wodder II)
* Wed May 17 2023 kastl@b1-systems.de
- adapt patch 0000-fix-big-endian-issues.patch
- update to 0.17.26:
  - Fix for error on edge cage for issue 459
- update to 0.17.25:
  - fix for regression while dumping wrapped strings with too many
    backslashes removed (issue 459, reported by `Lele Gaifax
    <https://sourceforge.net/u/lele/profile/>`__)
- update to 0.17.24:
  - rewrite of ``CommentedMap.insert()``. If you have a merge key
    in the YAML document for the mapping you insert to, the
    position value should be the one as you look at the YAML input.
    This fixes issue 453 where other keys of a merged in mapping
    would show up after an insert (reported by `Alex Miller
    <https://sourceforge.net/u/millerdevel/profile/>`__). It also
    fixes a call to `.insert()` resulting into the merge key to
    move to be the first key if it wasn't already and it is also
    now possible to insert a key before a merge key (even if the
    fist key in the mapping).
  - fix (in the pure Python implementation including default) for
    issue 447.  (reported by `Jack Cherng
    <https://sourceforge.net/u/jfcherng/profile/>`__, also brought
    up by brent on `StackOverflow
    <https://stackoverflow.com/q/40072485/1307905>`__)
- update to 0.17.23:
  - fix 458, error on plain scalars starting with word longer than
    width.  (reported by `Kyle Larose
    <https://sourceforge.net/u/klarose/profile/>`__)
  - fix for ``.update()`` no longer correctly handling keyword
    arguments (reported by John Lin on <StackOverflow
    `<https://stackoverflow.com/q/76089100/1307905>`__)
  - fix issue 454: high Unicode (emojis) in quoted strings always
    escaped (reported by `Michal Čihař
    <https://sourceforge.net/u/nijel/profile/>`__ based on a
    question on StackOverflow).
  - fix issue with emitter conservatively inserting extra
    backslashes in wrapped quoted strings (reported by thebenman on
    `StackOverflow
    <https://stackoverflow.com/q/75631454/1307905>`__)
- update to 0.17.22:
  - fix issue 449 where the second exclamation marks got URL
    encoded (reported and fixing PR provided by `John Stark
    <https://sourceforge.net/u/jods/profile/>`__)
  - fix issue with indent != 2 and literal scalars with empty first
    line (reported by wrdis on `StackOverflow
    <https://stackoverflow.com/q/75584262/1307905>`__)
  - updated __repr__ of CommentedMap, now that Python's dict is
    ordered -> no more ordereddict(list-of-tuples)
  - merge MR 4, handling OctalInt in YAML 1.1 (provided by `Jacob
    Floyd <https://sourceforge.net/u/cognifloyd/profile/>`_)
  - fix loading of `!!float 42` (reported by Eric on `Stack
    overflow <https://stackoverflow.com/a/71555107/1307905>`_)
  - line numbers are now set on `CommentedKeySeq` and
    `CommentedKeyMap` (which are created if you have a sequence
    resp. mapping as the key in a mapping)
  - plain scalars: put single words longer than width on a line of
    their own, instead of after the previous line (issue 427,
    reported by `Antoine Cotten
    <https://sourceforge.net/u/antoineco/profile/>`_). Caveat: this
    currently results in a space ending the previous line.
  - fix for folded scalar part of 421: comments after ">" on first
    line of folded scalars are now preserved (as were those in the
    same position on literal scalars).  Issue reported by Jacob
    Floyd.
  - added stacklevel to warnings
  - typing changed from Py2 compatible comments to Py3, removed
    various Py2-isms
* Fri Apr 21 2023 dmueller@suse.com
- add sle15_python_module_pythons (jsc#PED-68)
* Tue Jul 19 2022 dmueller@suse.com
- update to 0.17.21:
  * fix bug in calling `.compose()` method with `pathlib.Path` instance.
* Thu Apr 28 2022 jbaier@suse.com
- add 0000-fix-big-endian-issues.patch to workaround issue 360 on big endian systems
* Mon Jan 10 2022 dmueller@suse.com
- update to 0.17.20:
  - fix error in microseconds while rounding datetime fractions >= 9999995
  - fix mypy problems
  - copy-paste error in folded scalar comment attachment
  - fix 411, indent error comment between key empty seq value
* Mon Nov 29 2021 dmueller@suse.com
- update to 0.17.17:
  * extract timestamp matching/creation to util
* Sat Oct 16 2021 dmueller@suse.com
- update to 0.17.16:
  - also handle issue 397 when comment is newline
  - fix issue 397, insert comment before key when a comment between key and value exists
  - fix issue 396, inserting key/val in merged-in dictionary
  - minor fix in attr handling
  - fix issue with anchor on registered class not preserved and those classes using package
    attrs with `@attr.s()`
  - fix error baseclass for ``DuplicateKeyErorr`` (reported by `Łukasz Rogalski
  - fix typo in reader error message, causing `KeyError` during reader error
* Sat Jul 17 2021 dmueller@suse.com
- update to 0.17.10:
  - fix issue 388, token with old comment structure != two elements
  - fix issue with updating CommentedMap
  - fix for issue 387 where templated anchors on tagged object did get set
    resulting in potential id reuse.
  - issue 385 also affected other deprecated loaders
  - merged type annotations update
  - deprecated round_trip_loader function not working
  - wasted a few hours getting rid of mypy warnings/errors
  - fix for issue 384 !!set with aliased entry resulting in broken YAML on rt
* Sun May  2 2021 buschmann23@opensuse.org
- update to 0.17.4
  * prevent (empty) comments from throwing assertion error comments
    (or empty line) will be dropped
- update to 0.17.3
  * fix for issue 382 caused by an error in a format string
  * allow expansion of aliases by setting
    yaml.composer.return_alias = lambda s: copy.deepcopy(s)
* Tue Mar 30 2021 mimi.vx@gmail.com
- update to 0.17.2
  * fix upstream packaging problems
* Fri Mar 26 2021 mimi.vx@gmail.com
- update to 0.17.0
  * drop python2 support
  * preparation for f-strings
* Fri Oct 16 2020 buschmann23@opensuse.org
- update to 0.16.12
  * update links in doc
- update to 0.16.11
  * workaround issue with setuptools 0.50 and importing pip
* Fri Feb 21 2020 mimi.vx@gmail.com
- update to 0.16.10 (bsc#1164458, CVE-2019-20478)
  * fix typchecking issue on TaggedScalar
  * fix error in dumping literal scalar in sequence with comments before element
  * fix empty string mapping key roundtripping with preservation of quotes as ? ‘
  * fix incorrect state setting in class constructor
* Mon Sep 16 2019 jayvdb@gmail.com
- Replace => with >= in BuildRequires
* Fri Sep  6 2019 mimi.vx@gmail.com
- update to 0.16.5
  * allow for YAML(typ=['unsafe', 'pytypes'])
  * fix output of TAG directives with #
  * move setting of version based on YAML directive to scanner, allowing to
    check for file version during TAG directive scanning
  * preserve YAML and TAG directives on roundtrip, correctly output # in URL
    for YAML 1.2
* Mon Aug 12 2019 mimi.vx@gmail.com
- ruamel.yaml.clib is now harddep
* Thu Aug  8 2019 mimi.vx@gmail.com
- update to 0.16.1
  * Allow '#' in tag URI as these are allowed in YAML 1.2
* Wed Aug  7 2019 mimi.vx@gmail.com
- update to 0.16.0
  * split c-library to separeate package (python-ruamel.yaml.clib)
* Mon Jul 15 2019 jayvdb@gmail.com
- Fix %%python_exec -> %%python_expand
- update to 0.15.99
  * add `py.typed` to distribution
  * more accurately specify repository in README
- from 0.15.98
  * pass memo on to deepcopy
  * regenerate ext/_ruamel_yaml.c with Cython version 0.29.12
    needed for Python 3.8 betas
* Tue May 21 2019 mimi.vx@gmail.com
- update to 0.15.96
  * fix failure to round-trip anchored scalars in block sequence
  * fix failure to indent comments on round-trip anchored block style
    scalars in block sequence
* Tue May 14 2019 mimi.vx@gmail.com
- update to 0.15.94
  * fix missing line-break after end-of-file comments not ending in
    line-break
  * fix failure to parse empty implicit flow mapping key
  * in YAML 1.1 plains scalars `y`, 'n', `Y`, and 'N' are now
    correctly recognised as booleans and such strings dumped quoted
* Thu Apr 18 2019 mimi.vx@gmail.com
- update to 0.15.92
  * fix failure to parse empty implicit block mapping key
  * allowing duplicate keys would not work for merge keys
  * fix issue with updating CommentedMap from list of tuples
* Fri Mar  1 2019 mimi.vx@gmail.com
-  update to 0.15.89
  * fix for items with flow-mapping in block sequence output on single line
  * fix for safe dumping erroring in creation of representereror when dumping namedtuple
  * fix inclusing of python code from the subpackage data
* Tue Jan 29 2019 mimi.vx@gmail.com
- update to 0.15.87
  * fix problem with empty lists and the code to reinsert merge keys
  * reinsert merge key in its old position
  * fix for issue with non-ASCII anchor names
  * fix for issue when parsing flow mapping value starting with colon
  * the types used by `SafeConstructor` for mappings and sequences can
    now by set by assigning to `XXXConstructor.yaml_base_dict_type`
    (and `..._list_type`), preventing the need to copy two methods
    with 50+ lines that had `var = {}` hardcoded.
  * fix for `CommentedMap.copy()` not returning `CommentedMap`
  * fix for bug in roundtripping aliases used as key
  * anchors and aliases on scalar int, float, string and bool are now preserved.
    Anchors do not need a referring alias for these
  * fix issue saving methods of metaclass derived classes
* Tue Dec  4 2018 mimi.vx@gmail.com
- update to 0.15.80
  * fix issue emitting BEL character when round-tripping invalid folded input
  * fix issue with anchors nested deeper than alias
* Fri Nov 30 2018 adrian@suse.de
- update to 0.15.78
  * setup issue for 3.8 (reported by Sidney Kuyateh)
  * setting yaml.sort_base_mapping_type_on_output = False, will prevent explicit sorting by keys in the base representer of mappings. Roundtrip already did not do this. Usage only makes real sense for Python 3.6+ (feature request by Sebastian Gerber).
  * implement Python version check in YAML metadata in _test/test_z_data.py
  * fix issue with empty mapping and sequence loaded as flow-style (mapping reported by Min RK, sequence by Maged Ahmed)
  * fix issue with single '?' scalar (reported by Terrance)
  * fix issue with duplicate merge keys (prompted by answering a StackOverflow question by math)
  * fix dropping of comment on rt before sequence item that is sequence item (reported by Thorsten Kampe)
  * fix irregular output on pre-comment in sequence within sequence (reported by Thorsten Kampe)
  * allow non-compact (i.e. next line) dumping sequence/mapping within sequence.
  * fix regression on explicit 1.1 loading with the C based scanner/parser (reported by Tomas Vavra)
* Mon Oct  1 2018 mimi.vx@gmail.com
- update to 0.15.71
  * added ``key`` and ``reverse`` parameter
  * indent root level literal scalars that have directive or document end
    markers at the beginning of a line
  * fix issue #232 revert to throw ParserError for unexcpected ``]``
    and ``}`` instead of IndexError.
  * fix issue with dump_all gobbling end-of-document comments on parsing
  * fix issue with parsabel, but incorrect output with nested flow-style sequences
  * fix issue with loading Python objects that have __setstate__ and recursion in parameters
  * reverted CommentedMap and CommentedSeq to subclass ordereddict resp. list,
    reimplemented merge maps so that both ``dict(**commented_map_instance)`` and JSON
    dumping works. This also allows checking with ``isinstance()`` on ``dict`` resp. ``list``.
  * fix regression where handcrafted CommentedMaps could not be initiated
  * fix regression with non-root literal scalars that needed indent indicator
  * tag:yaml.org,2002:python/object/apply now also uses __qualname__ on PY3
* Fri Aug 31 2018 mimi.vx@gmail.com
- update to 0.15.64
  * support round-trip of tagged sequences: !Arg [a, {b: 1}]
  * fix issue when roundtripping floats starting with a dot such as .5
  * C based reader/scanner & emitter now allow setting of 1.2 as YAML version
* Tue Aug 28 2018 mimi.vx@gmail.com
- update to 0.15.61
  * support for round-tripping folded style scalars
  * speed up of scanning (~30%% depending on the input)
  * cleanup for mypy
  * issue with C based loader and leading zeros
  * simple mappings can now be used as keys when round-tripping
  * Fix that CommentedSeq could no longer be used in adding or do a sort
  * fix issue with python -O optimizing away code
  * unmade CommentedSeq a subclass of list.
  * fix issue where a comment could pop-up twice in the output
  * fix issue where JSON object (mapping) without spaces was not parsed properly
  * ix issue where comments after empty flow-style mappings were not emitted
  * fix issue with flow style mapping with comments gobbled newline
  * fix issue where single ‘+’ under YAML 1.2 was interpreted as integer, erroring out
  * added .copy() mapping representation for round-tripping
  * Fix method name dumps (were not dotted) and loads
  * Allow YAML() as a context manager for output
  * Fix issue with incorrect type information for load() and dump()
  * fixed DeprecationWarning for importing from collections on 3.7
  * After adding failing test for YAML.load_all(Path()), remove StopIteration
* Sun Jul 15 2018 mimi.vx@gmail.com
- update to 0.15.44
  * fix for losing precision when roundtripping floats by
  * decoding unicode escaped tags on Python2
  * add detection of C-compile failure
  * fix regression showing only on narrow Python 2.7
  * ``register_class()`` now returns class
* Wed Apr  4 2018 mimi.vx@gmail.com
- update to 0.15.37
  * fix incompatibility of C extension with 3.7
* Tue Jan  9 2018 mimi.vx@gmail.com
- update to 0.15.35
  * allow None as stream when specifying transform parameters to YAML.dump()
* Thu Oct 12 2017 mimi.vx@gmail.com
- update to 0.15.34
  * fix for issue 157: CDumper not dumping floats
  * support for “undefined” round-tripping tagged scalar objects
  * fix issue 148: replace cryptic error message when using !!timestamp with
  an incorrectly formatted or non- scalar.
  * allow setting yaml.default_flow_style = None (default: False) for for typ='rt'.
  * fix for issue 149: multiplications on ScalarFloat now return float
  * fix Comment dumping
  * fix for issue with “compact JSON” not parsing: {"in":{},"out":{}}
  * fix issue #51: different indents for mappings and sequences
  * fix for flow sequence/mapping as element/value of block sequence
  with sequence-indent minus dash-offset not equal two.
  * fix issue #61: merge of merge cannot be __repr__-ed
  * fix issue 62, YAML 1.2 allows ? and : in plain scalars if non-ambigious
  * fix lists within lists which would make comments disappear
  * fix for disappearing comment after empty flow sequence
  * fix for problem with dumping (unloaded) floats
  * added ScalarFloat which supports roundtripping of 23.1, 23.100, 42.00E+56,
  0.0, -0.0 etc. while keeping the format. Underscores in mantissas
  are not preserved/supported
  * (finally) fixed longstanding issue 23, now handling comment between block
  mapping key and value correctly
  * warn on YAML 1.1 float input that is incorrect
  * allow setting of boolean representation (false, true)
  by using: yaml.boolean_representation = [u'False', u'True']
  * fix for round_tripping integers on 2.7.X > sys.maxint
  * fix for round_tripping singe excl. mark tags doubling
  * fix for writing unicode in new API,
  * added object constructor for rt, decorator yaml_object to replace YAMLObject.
  * fix for problem using load_all with Path() instance
  * fix for load_all in combination with zero indent block style literal
  (pure=True only!)
  * missing pure attribute on YAML useful for implementing !include tag
  constructor for including YAML files in a YAML file
  * some documentation improvements
  * trigger of doc build on new revision
  * support for Unicode supplementary Plane output
  * fix for issue 135, typ=’safe’ not dumping in Python 2.7
  * fix for issue 133, in setup.py: change ModuleNotFoundError to ImportError
  * suppress duplicate key warning on mappings with merge keys
  * remove fatal dependency of setup.py on wheel package
  * fix for issue 130, regression in nested merge keys
  * top level PreservedScalarString not indented if not explicitly asked to
  * some mypy additions
  * fix for issue 127: tagged scalars were always quoted and seperated by
  a newline when in a block sequence
  * allow plug-in install via install ruamel.yaml[jinja2]
  * add plug-in mechanism for load/dump pre resp. post-processing
  * a set() with duplicate elements now throws error in rt loading
  * support for toplevel column zero literal/folded scalar in explicit documents
  * repeat load() on a single YAML() instance would fail.
  * transform parameter on dump that expects a function taking a string
  and returning a string. This allows transformation of the output before
  it is written to stream. This forces creation of the complete output in memory!
  * some updates to the docs
  * update to conform to mypy 0.511: mypy –strict
  * duplicate keys in mappings generate an error
  * dependecy on ruamel.ordereddict for 2.7 now via extras_require
  * it is now allowed to pass in a pathlib.Path as “stream” parameter
  to all load/dump functions
  * passing in a non-supported object (e.g. a string) as “stream” will result
  in a much more meaningful YAMLStreamError.
  * assigning a normal string value to an existing CommentedMap key
  or CommentedSeq element will result in a value cast to the previous
  value’s type if possible.
  * added YAML class for new API
  * fix for issue 119, deepcopy not returning subclasses
  * fix for issue 103 allowing implicit documents after document end marker
  line (...) in YAML 1.2
  * fix problem with emitting using cyaml
* Mon Apr 24 2017 aloisio@gmx.com
- Update to 0.14.9 (see included CHANGES file)
- Converted to single-spec
- LICENSE file is now provided internally, so dropped Source1
- Dropped python-ruamel.ordereddict as build requirement
* Tue Oct 11 2016 rjschwei@suse.com
- Initial build    (FATE#321630, bsc#1002895)
  + Include in SLES 12
  + Version 0.12.14
